# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: operator.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2
from biostarPython.service import auth_pb2 as auth__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='operator.proto',
  package='operator',
  syntax='proto3',
  serialized_options=_b('\n\033com.supremainc.sdk.operatorP\001Z\030biostar/service/operator'),
  serialized_pb=_b('\n\x0eoperator.proto\x12\x08operator\x1a\terr.proto\x1a\nauth.proto\"\"\n\x0eGetListRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"4\n\x0fGetListResponse\x12!\n\toperators\x18\x01 \x03(\x0b\x32\x0e.auth.Operator\"A\n\nAddRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12!\n\toperators\x18\x02 \x03(\x0b\x32\x0e.auth.Operator\"\r\n\x0b\x41\x64\x64Response\"G\n\x0f\x41\x64\x64MultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12!\n\toperators\x18\x02 \x03(\x0b\x32\x0e.auth.Operator\"<\n\x10\x41\x64\x64MultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"6\n\rDeleteRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x13\n\x0boperatorIDs\x18\x02 \x03(\t\"\x10\n\x0e\x44\x65leteResponse\"<\n\x12\x44\x65leteMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x13\n\x0boperatorIDs\x18\x02 \x03(\t\"?\n\x13\x44\x65leteMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"$\n\x10\x44\x65leteAllRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x13\n\x11\x44\x65leteAllResponse\"*\n\x15\x44\x65leteAllMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\"B\n\x16\x44\x65leteAllMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse2\xe5\x03\n\x08Operator\x12>\n\x07GetList\x12\x18.operator.GetListRequest\x1a\x19.operator.GetListResponse\x12\x32\n\x03\x41\x64\x64\x12\x14.operator.AddRequest\x1a\x15.operator.AddResponse\x12\x41\n\x08\x41\x64\x64Multi\x12\x19.operator.AddMultiRequest\x1a\x1a.operator.AddMultiResponse\x12;\n\x06\x44\x65lete\x12\x17.operator.DeleteRequest\x1a\x18.operator.DeleteResponse\x12J\n\x0b\x44\x65leteMulti\x12\x1c.operator.DeleteMultiRequest\x1a\x1d.operator.DeleteMultiResponse\x12\x44\n\tDeleteAll\x12\x1a.operator.DeleteAllRequest\x1a\x1b.operator.DeleteAllResponse\x12S\n\x0e\x44\x65leteAllMulti\x12\x1f.operator.DeleteAllMultiRequest\x1a .operator.DeleteAllMultiResponseB9\n\x1b\x63om.supremainc.sdk.operatorP\x01Z\x18\x62iostar/service/operatorb\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,auth__pb2.DESCRIPTOR,])




_GETLISTREQUEST = _descriptor.Descriptor(
  name='GetListRequest',
  full_name='operator.GetListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='operator.GetListRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=85,
)


_GETLISTRESPONSE = _descriptor.Descriptor(
  name='GetListResponse',
  full_name='operator.GetListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operators', full_name='operator.GetListResponse.operators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=139,
)


_ADDREQUEST = _descriptor.Descriptor(
  name='AddRequest',
  full_name='operator.AddRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='operator.AddRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operators', full_name='operator.AddRequest.operators', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=206,
)


_ADDRESPONSE = _descriptor.Descriptor(
  name='AddResponse',
  full_name='operator.AddResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=208,
  serialized_end=221,
)


_ADDMULTIREQUEST = _descriptor.Descriptor(
  name='AddMultiRequest',
  full_name='operator.AddMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='operator.AddMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operators', full_name='operator.AddMultiRequest.operators', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=223,
  serialized_end=294,
)


_ADDMULTIRESPONSE = _descriptor.Descriptor(
  name='AddMultiResponse',
  full_name='operator.AddMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='operator.AddMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=296,
  serialized_end=356,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='operator.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='operator.DeleteRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operatorIDs', full_name='operator.DeleteRequest.operatorIDs', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=358,
  serialized_end=412,
)


_DELETERESPONSE = _descriptor.Descriptor(
  name='DeleteResponse',
  full_name='operator.DeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=414,
  serialized_end=430,
)


_DELETEMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteMultiRequest',
  full_name='operator.DeleteMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='operator.DeleteMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operatorIDs', full_name='operator.DeleteMultiRequest.operatorIDs', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=492,
)


_DELETEMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteMultiResponse',
  full_name='operator.DeleteMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='operator.DeleteMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=494,
  serialized_end=557,
)


_DELETEALLREQUEST = _descriptor.Descriptor(
  name='DeleteAllRequest',
  full_name='operator.DeleteAllRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='operator.DeleteAllRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=559,
  serialized_end=595,
)


_DELETEALLRESPONSE = _descriptor.Descriptor(
  name='DeleteAllResponse',
  full_name='operator.DeleteAllResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=597,
  serialized_end=616,
)


_DELETEALLMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteAllMultiRequest',
  full_name='operator.DeleteAllMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='operator.DeleteAllMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=618,
  serialized_end=660,
)


_DELETEALLMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteAllMultiResponse',
  full_name='operator.DeleteAllMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='operator.DeleteAllMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=662,
  serialized_end=728,
)

_GETLISTRESPONSE.fields_by_name['operators'].message_type = auth__pb2._OPERATOR
_ADDREQUEST.fields_by_name['operators'].message_type = auth__pb2._OPERATOR
_ADDMULTIREQUEST.fields_by_name['operators'].message_type = auth__pb2._OPERATOR
_ADDMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEALLMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['GetListRequest'] = _GETLISTREQUEST
DESCRIPTOR.message_types_by_name['GetListResponse'] = _GETLISTRESPONSE
DESCRIPTOR.message_types_by_name['AddRequest'] = _ADDREQUEST
DESCRIPTOR.message_types_by_name['AddResponse'] = _ADDRESPONSE
DESCRIPTOR.message_types_by_name['AddMultiRequest'] = _ADDMULTIREQUEST
DESCRIPTOR.message_types_by_name['AddMultiResponse'] = _ADDMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
DESCRIPTOR.message_types_by_name['DeleteResponse'] = _DELETERESPONSE
DESCRIPTOR.message_types_by_name['DeleteMultiRequest'] = _DELETEMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteMultiResponse'] = _DELETEMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllRequest'] = _DELETEALLREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllResponse'] = _DELETEALLRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllMultiRequest'] = _DELETEALLMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllMultiResponse'] = _DELETEALLMULTIRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetListRequest = _reflection.GeneratedProtocolMessageType('GetListRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETLISTREQUEST,
  __module__ = 'operator_pb2'
  # @@protoc_insertion_point(class_scope:operator.GetListRequest)
  ))
_sym_db.RegisterMessage(GetListRequest)

GetListResponse = _reflection.GeneratedProtocolMessageType('GetListResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETLISTRESPONSE,
  __module__ = 'operator_pb2'
  # @@protoc_insertion_point(class_scope:operator.GetListResponse)
  ))
_sym_db.RegisterMessage(GetListResponse)

AddRequest = _reflection.GeneratedProtocolMessageType('AddRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDREQUEST,
  __module__ = 'operator_pb2'
  # @@protoc_insertion_point(class_scope:operator.AddRequest)
  ))
_sym_db.RegisterMessage(AddRequest)

AddResponse = _reflection.GeneratedProtocolMessageType('AddResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDRESPONSE,
  __module__ = 'operator_pb2'
  # @@protoc_insertion_point(class_scope:operator.AddResponse)
  ))
_sym_db.RegisterMessage(AddResponse)

AddMultiRequest = _reflection.GeneratedProtocolMessageType('AddMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDMULTIREQUEST,
  __module__ = 'operator_pb2'
  # @@protoc_insertion_point(class_scope:operator.AddMultiRequest)
  ))
_sym_db.RegisterMessage(AddMultiRequest)

AddMultiResponse = _reflection.GeneratedProtocolMessageType('AddMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDMULTIRESPONSE,
  __module__ = 'operator_pb2'
  # @@protoc_insertion_point(class_scope:operator.AddMultiResponse)
  ))
_sym_db.RegisterMessage(AddMultiResponse)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'operator_pb2'
  # @@protoc_insertion_point(class_scope:operator.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)

DeleteResponse = _reflection.GeneratedProtocolMessageType('DeleteResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETERESPONSE,
  __module__ = 'operator_pb2'
  # @@protoc_insertion_point(class_scope:operator.DeleteResponse)
  ))
_sym_db.RegisterMessage(DeleteResponse)

DeleteMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEMULTIREQUEST,
  __module__ = 'operator_pb2'
  # @@protoc_insertion_point(class_scope:operator.DeleteMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteMultiRequest)

DeleteMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEMULTIRESPONSE,
  __module__ = 'operator_pb2'
  # @@protoc_insertion_point(class_scope:operator.DeleteMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteMultiResponse)

DeleteAllRequest = _reflection.GeneratedProtocolMessageType('DeleteAllRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLREQUEST,
  __module__ = 'operator_pb2'
  # @@protoc_insertion_point(class_scope:operator.DeleteAllRequest)
  ))
_sym_db.RegisterMessage(DeleteAllRequest)

DeleteAllResponse = _reflection.GeneratedProtocolMessageType('DeleteAllResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLRESPONSE,
  __module__ = 'operator_pb2'
  # @@protoc_insertion_point(class_scope:operator.DeleteAllResponse)
  ))
_sym_db.RegisterMessage(DeleteAllResponse)

DeleteAllMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteAllMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLMULTIREQUEST,
  __module__ = 'operator_pb2'
  # @@protoc_insertion_point(class_scope:operator.DeleteAllMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteAllMultiRequest)

DeleteAllMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteAllMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLMULTIRESPONSE,
  __module__ = 'operator_pb2'
  # @@protoc_insertion_point(class_scope:operator.DeleteAllMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteAllMultiResponse)


DESCRIPTOR._options = None

_OPERATOR = _descriptor.ServiceDescriptor(
  name='Operator',
  full_name='operator.Operator',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=731,
  serialized_end=1216,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetList',
    full_name='operator.Operator.GetList',
    index=0,
    containing_service=None,
    input_type=_GETLISTREQUEST,
    output_type=_GETLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Add',
    full_name='operator.Operator.Add',
    index=1,
    containing_service=None,
    input_type=_ADDREQUEST,
    output_type=_ADDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddMulti',
    full_name='operator.Operator.AddMulti',
    index=2,
    containing_service=None,
    input_type=_ADDMULTIREQUEST,
    output_type=_ADDMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='operator.Operator.Delete',
    index=3,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=_DELETERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteMulti',
    full_name='operator.Operator.DeleteMulti',
    index=4,
    containing_service=None,
    input_type=_DELETEMULTIREQUEST,
    output_type=_DELETEMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAll',
    full_name='operator.Operator.DeleteAll',
    index=5,
    containing_service=None,
    input_type=_DELETEALLREQUEST,
    output_type=_DELETEALLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllMulti',
    full_name='operator.Operator.DeleteAllMulti',
    index=6,
    containing_service=None,
    input_type=_DELETEALLMULTIREQUEST,
    output_type=_DELETEALLMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_OPERATOR)

DESCRIPTOR.services_by_name['Operator'] = _OPERATOR

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import access_pb2 as access__pb2


class AccessStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetList = channel.unary_unary(
        '/access.Access/GetList',
        request_serializer=access__pb2.GetListRequest.SerializeToString,
        response_deserializer=access__pb2.GetListResponse.FromString,
        )
    self.Add = channel.unary_unary(
        '/access.Access/Add',
        request_serializer=access__pb2.AddRequest.SerializeToString,
        response_deserializer=access__pb2.AddResponse.FromString,
        )
    self.AddMulti = channel.unary_unary(
        '/access.Access/AddMulti',
        request_serializer=access__pb2.AddMultiRequest.SerializeToString,
        response_deserializer=access__pb2.AddMultiResponse.FromString,
        )
    self.Delete = channel.unary_unary(
        '/access.Access/Delete',
        request_serializer=access__pb2.DeleteRequest.SerializeToString,
        response_deserializer=access__pb2.DeleteResponse.FromString,
        )
    self.DeleteMulti = channel.unary_unary(
        '/access.Access/DeleteMulti',
        request_serializer=access__pb2.DeleteMultiRequest.SerializeToString,
        response_deserializer=access__pb2.DeleteMultiResponse.FromString,
        )
    self.DeleteAll = channel.unary_unary(
        '/access.Access/DeleteAll',
        request_serializer=access__pb2.DeleteAllRequest.SerializeToString,
        response_deserializer=access__pb2.DeleteAllResponse.FromString,
        )
    self.DeleteAllMulti = channel.unary_unary(
        '/access.Access/DeleteAllMulti',
        request_serializer=access__pb2.DeleteAllMultiRequest.SerializeToString,
        response_deserializer=access__pb2.DeleteAllMultiResponse.FromString,
        )
    self.GetLevelList = channel.unary_unary(
        '/access.Access/GetLevelList',
        request_serializer=access__pb2.GetLevelListRequest.SerializeToString,
        response_deserializer=access__pb2.GetLevelListResponse.FromString,
        )
    self.AddLevel = channel.unary_unary(
        '/access.Access/AddLevel',
        request_serializer=access__pb2.AddLevelRequest.SerializeToString,
        response_deserializer=access__pb2.AddLevelResponse.FromString,
        )
    self.AddLevelMulti = channel.unary_unary(
        '/access.Access/AddLevelMulti',
        request_serializer=access__pb2.AddLevelMultiRequest.SerializeToString,
        response_deserializer=access__pb2.AddLevelMultiResponse.FromString,
        )
    self.DeleteLevel = channel.unary_unary(
        '/access.Access/DeleteLevel',
        request_serializer=access__pb2.DeleteLevelRequest.SerializeToString,
        response_deserializer=access__pb2.DeleteLevelResponse.FromString,
        )
    self.DeleteLevelMulti = channel.unary_unary(
        '/access.Access/DeleteLevelMulti',
        request_serializer=access__pb2.DeleteLevelMultiRequest.SerializeToString,
        response_deserializer=access__pb2.DeleteLevelMultiResponse.FromString,
        )
    self.DeleteAllLevel = channel.unary_unary(
        '/access.Access/DeleteAllLevel',
        request_serializer=access__pb2.DeleteAllLevelRequest.SerializeToString,
        response_deserializer=access__pb2.DeleteAllLevelResponse.FromString,
        )
    self.DeleteAllLevelMulti = channel.unary_unary(
        '/access.Access/DeleteAllLevelMulti',
        request_serializer=access__pb2.DeleteAllLevelMultiRequest.SerializeToString,
        response_deserializer=access__pb2.DeleteAllLevelMultiResponse.FromString,
        )
    self.GetFloorLevelList = channel.unary_unary(
        '/access.Access/GetFloorLevelList',
        request_serializer=access__pb2.GetFloorLevelListRequest.SerializeToString,
        response_deserializer=access__pb2.GetFloorLevelListResponse.FromString,
        )
    self.AddFloorLevel = channel.unary_unary(
        '/access.Access/AddFloorLevel',
        request_serializer=access__pb2.AddFloorLevelRequest.SerializeToString,
        response_deserializer=access__pb2.AddFloorLevelResponse.FromString,
        )
    self.AddFloorLevelMulti = channel.unary_unary(
        '/access.Access/AddFloorLevelMulti',
        request_serializer=access__pb2.AddFloorLevelMultiRequest.SerializeToString,
        response_deserializer=access__pb2.AddFloorLevelMultiResponse.FromString,
        )
    self.DeleteFloorLevel = channel.unary_unary(
        '/access.Access/DeleteFloorLevel',
        request_serializer=access__pb2.DeleteFloorLevelRequest.SerializeToString,
        response_deserializer=access__pb2.DeleteFloorLevelResponse.FromString,
        )
    self.DeleteFloorLevelMulti = channel.unary_unary(
        '/access.Access/DeleteFloorLevelMulti',
        request_serializer=access__pb2.DeleteFloorLevelMultiRequest.SerializeToString,
        response_deserializer=access__pb2.DeleteFloorLevelMultiResponse.FromString,
        )
    self.DeleteAllFloorLevel = channel.unary_unary(
        '/access.Access/DeleteAllFloorLevel',
        request_serializer=access__pb2.DeleteAllFloorLevelRequest.SerializeToString,
        response_deserializer=access__pb2.DeleteAllFloorLevelResponse.FromString,
        )
    self.DeleteAllFloorLevelMulti = channel.unary_unary(
        '/access.Access/DeleteAllFloorLevelMulti',
        request_serializer=access__pb2.DeleteAllFloorLevelMultiRequest.SerializeToString,
        response_deserializer=access__pb2.DeleteAllFloorLevelMultiResponse.FromString,
        )


class AccessServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetList(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Add(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAll(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAllMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetLevelList(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddLevel(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddLevelMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteLevel(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteLevelMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAllLevel(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAllLevelMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetFloorLevelList(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddFloorLevel(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddFloorLevelMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteFloorLevel(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteFloorLevelMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAllFloorLevel(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAllFloorLevelMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AccessServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetList': grpc.unary_unary_rpc_method_handler(
          servicer.GetList,
          request_deserializer=access__pb2.GetListRequest.FromString,
          response_serializer=access__pb2.GetListResponse.SerializeToString,
      ),
      'Add': grpc.unary_unary_rpc_method_handler(
          servicer.Add,
          request_deserializer=access__pb2.AddRequest.FromString,
          response_serializer=access__pb2.AddResponse.SerializeToString,
      ),
      'AddMulti': grpc.unary_unary_rpc_method_handler(
          servicer.AddMulti,
          request_deserializer=access__pb2.AddMultiRequest.FromString,
          response_serializer=access__pb2.AddMultiResponse.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=access__pb2.DeleteRequest.FromString,
          response_serializer=access__pb2.DeleteResponse.SerializeToString,
      ),
      'DeleteMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteMulti,
          request_deserializer=access__pb2.DeleteMultiRequest.FromString,
          response_serializer=access__pb2.DeleteMultiResponse.SerializeToString,
      ),
      'DeleteAll': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAll,
          request_deserializer=access__pb2.DeleteAllRequest.FromString,
          response_serializer=access__pb2.DeleteAllResponse.SerializeToString,
      ),
      'DeleteAllMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAllMulti,
          request_deserializer=access__pb2.DeleteAllMultiRequest.FromString,
          response_serializer=access__pb2.DeleteAllMultiResponse.SerializeToString,
      ),
      'GetLevelList': grpc.unary_unary_rpc_method_handler(
          servicer.GetLevelList,
          request_deserializer=access__pb2.GetLevelListRequest.FromString,
          response_serializer=access__pb2.GetLevelListResponse.SerializeToString,
      ),
      'AddLevel': grpc.unary_unary_rpc_method_handler(
          servicer.AddLevel,
          request_deserializer=access__pb2.AddLevelRequest.FromString,
          response_serializer=access__pb2.AddLevelResponse.SerializeToString,
      ),
      'AddLevelMulti': grpc.unary_unary_rpc_method_handler(
          servicer.AddLevelMulti,
          request_deserializer=access__pb2.AddLevelMultiRequest.FromString,
          response_serializer=access__pb2.AddLevelMultiResponse.SerializeToString,
      ),
      'DeleteLevel': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteLevel,
          request_deserializer=access__pb2.DeleteLevelRequest.FromString,
          response_serializer=access__pb2.DeleteLevelResponse.SerializeToString,
      ),
      'DeleteLevelMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteLevelMulti,
          request_deserializer=access__pb2.DeleteLevelMultiRequest.FromString,
          response_serializer=access__pb2.DeleteLevelMultiResponse.SerializeToString,
      ),
      'DeleteAllLevel': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAllLevel,
          request_deserializer=access__pb2.DeleteAllLevelRequest.FromString,
          response_serializer=access__pb2.DeleteAllLevelResponse.SerializeToString,
      ),
      'DeleteAllLevelMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAllLevelMulti,
          request_deserializer=access__pb2.DeleteAllLevelMultiRequest.FromString,
          response_serializer=access__pb2.DeleteAllLevelMultiResponse.SerializeToString,
      ),
      'GetFloorLevelList': grpc.unary_unary_rpc_method_handler(
          servicer.GetFloorLevelList,
          request_deserializer=access__pb2.GetFloorLevelListRequest.FromString,
          response_serializer=access__pb2.GetFloorLevelListResponse.SerializeToString,
      ),
      'AddFloorLevel': grpc.unary_unary_rpc_method_handler(
          servicer.AddFloorLevel,
          request_deserializer=access__pb2.AddFloorLevelRequest.FromString,
          response_serializer=access__pb2.AddFloorLevelResponse.SerializeToString,
      ),
      'AddFloorLevelMulti': grpc.unary_unary_rpc_method_handler(
          servicer.AddFloorLevelMulti,
          request_deserializer=access__pb2.AddFloorLevelMultiRequest.FromString,
          response_serializer=access__pb2.AddFloorLevelMultiResponse.SerializeToString,
      ),
      'DeleteFloorLevel': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteFloorLevel,
          request_deserializer=access__pb2.DeleteFloorLevelRequest.FromString,
          response_serializer=access__pb2.DeleteFloorLevelResponse.SerializeToString,
      ),
      'DeleteFloorLevelMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteFloorLevelMulti,
          request_deserializer=access__pb2.DeleteFloorLevelMultiRequest.FromString,
          response_serializer=access__pb2.DeleteFloorLevelMultiResponse.SerializeToString,
      ),
      'DeleteAllFloorLevel': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAllFloorLevel,
          request_deserializer=access__pb2.DeleteAllFloorLevelRequest.FromString,
          response_serializer=access__pb2.DeleteAllFloorLevelResponse.SerializeToString,
      ),
      'DeleteAllFloorLevelMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAllFloorLevelMulti,
          request_deserializer=access__pb2.DeleteAllFloorLevelMultiRequest.FromString,
          response_serializer=access__pb2.DeleteAllFloorLevelMultiResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'access.Access', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import tna_pb2 as tna__pb2


class TNAStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetConfig = channel.unary_unary(
        '/tna.TNA/GetConfig',
        request_serializer=tna__pb2.GetConfigRequest.SerializeToString,
        response_deserializer=tna__pb2.GetConfigResponse.FromString,
        )
    self.SetConfig = channel.unary_unary(
        '/tna.TNA/SetConfig',
        request_serializer=tna__pb2.SetConfigRequest.SerializeToString,
        response_deserializer=tna__pb2.SetConfigResponse.FromString,
        )
    self.SetConfigMulti = channel.unary_unary(
        '/tna.TNA/SetConfigMulti',
        request_serializer=tna__pb2.SetConfigMultiRequest.SerializeToString,
        response_deserializer=tna__pb2.SetConfigMultiResponse.FromString,
        )
    self.GetTNALog = channel.unary_unary(
        '/tna.TNA/GetTNALog',
        request_serializer=tna__pb2.GetTNALogRequest.SerializeToString,
        response_deserializer=tna__pb2.GetTNALogResponse.FromString,
        )
    self.GetJobCodeLog = channel.unary_unary(
        '/tna.TNA/GetJobCodeLog',
        request_serializer=tna__pb2.GetJobCodeLogRequest.SerializeToString,
        response_deserializer=tna__pb2.GetJobCodeLogResponse.FromString,
        )


class TNAServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetConfigMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetTNALog(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetJobCodeLog(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_TNAServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetConfig': grpc.unary_unary_rpc_method_handler(
          servicer.GetConfig,
          request_deserializer=tna__pb2.GetConfigRequest.FromString,
          response_serializer=tna__pb2.GetConfigResponse.SerializeToString,
      ),
      'SetConfig': grpc.unary_unary_rpc_method_handler(
          servicer.SetConfig,
          request_deserializer=tna__pb2.SetConfigRequest.FromString,
          response_serializer=tna__pb2.SetConfigResponse.SerializeToString,
      ),
      'SetConfigMulti': grpc.unary_unary_rpc_method_handler(
          servicer.SetConfigMulti,
          request_deserializer=tna__pb2.SetConfigMultiRequest.FromString,
          response_serializer=tna__pb2.SetConfigMultiResponse.SerializeToString,
      ),
      'GetTNALog': grpc.unary_unary_rpc_method_handler(
          servicer.GetTNALog,
          request_deserializer=tna__pb2.GetTNALogRequest.FromString,
          response_serializer=tna__pb2.GetTNALogResponse.SerializeToString,
      ),
      'GetJobCodeLog': grpc.unary_unary_rpc_method_handler(
          servicer.GetJobCodeLog,
          request_deserializer=tna__pb2.GetJobCodeLogRequest.FromString,
          response_serializer=tna__pb2.GetJobCodeLogResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'tna.TNA', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import time_pb2 as time__pb2


class TimeStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/time.Time/Get',
        request_serializer=time__pb2.GetRequest.SerializeToString,
        response_deserializer=time__pb2.GetResponse.FromString,
        )
    self.Set = channel.unary_unary(
        '/time.Time/Set',
        request_serializer=time__pb2.SetRequest.SerializeToString,
        response_deserializer=time__pb2.SetResponse.FromString,
        )
    self.SetMulti = channel.unary_unary(
        '/time.Time/SetMulti',
        request_serializer=time__pb2.SetMultiRequest.SerializeToString,
        response_deserializer=time__pb2.SetMultiResponse.FromString,
        )
    self.GetConfig = channel.unary_unary(
        '/time.Time/GetConfig',
        request_serializer=time__pb2.GetConfigRequest.SerializeToString,
        response_deserializer=time__pb2.GetConfigResponse.FromString,
        )
    self.SetConfig = channel.unary_unary(
        '/time.Time/SetConfig',
        request_serializer=time__pb2.SetConfigRequest.SerializeToString,
        response_deserializer=time__pb2.SetConfigResponse.FromString,
        )
    self.SetConfigMulti = channel.unary_unary(
        '/time.Time/SetConfigMulti',
        request_serializer=time__pb2.SetConfigMultiRequest.SerializeToString,
        response_deserializer=time__pb2.SetConfigMultiResponse.FromString,
        )
    self.GetDSTConfig = channel.unary_unary(
        '/time.Time/GetDSTConfig',
        request_serializer=time__pb2.GetDSTConfigRequest.SerializeToString,
        response_deserializer=time__pb2.GetDSTConfigResponse.FromString,
        )
    self.SetDSTConfig = channel.unary_unary(
        '/time.Time/SetDSTConfig',
        request_serializer=time__pb2.SetDSTConfigRequest.SerializeToString,
        response_deserializer=time__pb2.SetDSTConfigResponse.FromString,
        )
    self.SetDSTConfigMulti = channel.unary_unary(
        '/time.Time/SetDSTConfigMulti',
        request_serializer=time__pb2.SetDSTConfigMultiRequest.SerializeToString,
        response_deserializer=time__pb2.SetDSTConfigMultiResponse.FromString,
        )


class TimeServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Set(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetConfigMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetDSTConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetDSTConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetDSTConfigMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_TimeServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=time__pb2.GetRequest.FromString,
          response_serializer=time__pb2.GetResponse.SerializeToString,
      ),
      'Set': grpc.unary_unary_rpc_method_handler(
          servicer.Set,
          request_deserializer=time__pb2.SetRequest.FromString,
          response_serializer=time__pb2.SetResponse.SerializeToString,
      ),
      'SetMulti': grpc.unary_unary_rpc_method_handler(
          servicer.SetMulti,
          request_deserializer=time__pb2.SetMultiRequest.FromString,
          response_serializer=time__pb2.SetMultiResponse.SerializeToString,
      ),
      'GetConfig': grpc.unary_unary_rpc_method_handler(
          servicer.GetConfig,
          request_deserializer=time__pb2.GetConfigRequest.FromString,
          response_serializer=time__pb2.GetConfigResponse.SerializeToString,
      ),
      'SetConfig': grpc.unary_unary_rpc_method_handler(
          servicer.SetConfig,
          request_deserializer=time__pb2.SetConfigRequest.FromString,
          response_serializer=time__pb2.SetConfigResponse.SerializeToString,
      ),
      'SetConfigMulti': grpc.unary_unary_rpc_method_handler(
          servicer.SetConfigMulti,
          request_deserializer=time__pb2.SetConfigMultiRequest.FromString,
          response_serializer=time__pb2.SetConfigMultiResponse.SerializeToString,
      ),
      'GetDSTConfig': grpc.unary_unary_rpc_method_handler(
          servicer.GetDSTConfig,
          request_deserializer=time__pb2.GetDSTConfigRequest.FromString,
          response_serializer=time__pb2.GetDSTConfigResponse.SerializeToString,
      ),
      'SetDSTConfig': grpc.unary_unary_rpc_method_handler(
          servicer.SetDSTConfig,
          request_deserializer=time__pb2.SetDSTConfigRequest.FromString,
          response_serializer=time__pb2.SetDSTConfigResponse.SerializeToString,
      ),
      'SetDSTConfigMulti': grpc.unary_unary_rpc_method_handler(
          servicer.SetDSTConfigMulti,
          request_deserializer=time__pb2.SetDSTConfigMultiRequest.FromString,
          response_serializer=time__pb2.SetDSTConfigMultiResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'time.Time', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
